==> ml_algo-15.6.5.tar.gz: test/linear_optimizer/linear_optimizer_type_json_converter_test.dart <==
import 'package:ml_algo/src/linear_optimizer/linear_optimizer_type.dart';
import 'package:ml_algo/src/linear_optimizer/linear_optimizer_type_json_converter.dart';
import 'package:ml_algo/src/linear_optimizer/linear_optimizer_type_json_encoded_values.dart';
import 'package:test/test.dart';

void main() {
  group('LinearOptimizerTypeJsonConverter', () {
    test('should decode ${LinearOptimizerType.gradient} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .fromJson(gradientLinearOptimizerTypeEncodedValue),
          LinearOptimizerType.gradient);
    });

    test('should decode ${LinearOptimizerType.coordinate} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .fromJson(coordinateLinearOptimizerTypeEncodedValue),
          LinearOptimizerType.coordinate);
    });

    test('should return null for unknown encoded value', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .fromJson('unknown_value'), null);
    });

    test('should encode ${LinearOptimizerType.gradient} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .toJson(LinearOptimizerType.gradient),
          gradientLinearOptimizerTypeEncodedValue);
    });

    test('should encode ${LinearOptimizerType.coordinate} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .toJson(LinearOptimizerType.coordinate),
          coordinateLinearOptimizerTypeEncodedValue);
    });

    test('should return null for unknown type', () {
      expect(const LinearOptimizerTypeJsonConverter().toJson(null), null);
    });
  });
}

==> ml_algo-16.0.2.tar.gz: test/linear_optimizer/linear_optimizer_type_json_converter_test.dart <==
import 'package:ml_algo/src/linear_optimizer/linear_optimizer_type.dart';
import 'package:ml_algo/src/linear_optimizer/linear_optimizer_type_json_converter.dart';
import 'package:ml_algo/src/linear_optimizer/linear_optimizer_type_json_encoded_values.dart';
import 'package:test/test.dart';

void main() {
  group('LinearOptimizerTypeJsonConverter', () {
    test('should decode ${LinearOptimizerType.gradient} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .fromJson(gradientLinearOptimizerTypeEncodedValue),
          LinearOptimizerType.gradient);
    });

    test('should decode ${LinearOptimizerType.coordinate} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .fromJson(coordinateLinearOptimizerTypeEncodedValue),
          LinearOptimizerType.coordinate);
    });

    test('should throw exception if unknown value is provided', () {
      expect(
            () => const LinearOptimizerTypeJsonConverter()
                .fromJson('unknown_value'),
          throwsException,
      );
    });

    test('should encode ${LinearOptimizerType.gradient} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .toJson(LinearOptimizerType.gradient),
          gradientLinearOptimizerTypeEncodedValue);
    });

    test('should encode ${LinearOptimizerType.coordinate} type', () {
      expect(const LinearOptimizerTypeJsonConverter()
          .toJson(LinearOptimizerType.coordinate),
          coordinateLinearOptimizerTypeEncodedValue);
    });
  });
}
